@@ -37,6 +37,12 @@ class DescribeDBInstancesRequest(RpcRequest):
 	def set_ResourceOwnerId(self,ResourceOwnerId):
 		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
 
+	def get_ConnectionString(self):
+		return self.get_query_params().get('ConnectionString')
+
+	def set_ConnectionString(self,ConnectionString):
+		self.add_query_param('ConnectionString',ConnectionString)
+
 	def get_EngineVersion(self):
 		return self.get_query_params().get('EngineVersion')
 
